==> kubernetes-model-apiextensions-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/ExternalDocumentationBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ExternalDocumentationBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationBuilder>{
  public ExternalDocumentationBuilder() {
    this(false);
  }
  public ExternalDocumentationBuilder(java.lang.Boolean validationEnabled) {
    this(new ExternalDocumentation(), validationEnabled);
  }
  public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent) {
    this(fluent, false);
  }
  public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ExternalDocumentation(), validationEnabled);
  }
  public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance) {
    this(fluent, instance, false);
  }
  public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance) {
    this(instance,false);
  }
  public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation build() {
    ExternalDocumentation buildable = new ExternalDocumentation(fluent.getDescription(),fluent.getUrl());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExternalDocumentationBuilder that = (ExternalDocumentationBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-apiextensions-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/ExternalDocumentationBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ExternalDocumentationBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationBuilder>{
  public ExternalDocumentationBuilder() {
    this(false);
  }
  public ExternalDocumentationBuilder(java.lang.Boolean validationEnabled) {
    this(new ExternalDocumentation(), validationEnabled);
  }
  public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent) {
    this(fluent, false);
  }
  public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ExternalDocumentation(), validationEnabled);
  }
  public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance) {
    this(fluent, instance, false);
  }
  public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance) {
    this(instance,false);
  }
  public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation build() {
    ExternalDocumentation buildable = new ExternalDocumentation(fluent.getDescription(),fluent.getUrl());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExternalDocumentationBuilder that = (ExternalDocumentationBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
